%global pkg skge

%global kernel_version_min 4.18.0-240.el8

# To pick a specific kernel use `--define "kernel_version 4.18.0-315.el8"`
# Otherwise the latest installed kernel-devel version later than
# %%{kernel_version_min} will be used.

%global kernel_version_latest %({ echo %{kernel_version_min}; rpm --query kernel-devel --queryformat '%%{VERSION}-%%{RELEASE}\\\n' | grep -v "package kernel-devel is not installed"; } | sort -V | sed -e '0,/^%{kernel_version_min}$/d' | tail -n 1)

%if "%{kernel_version_latest}" != ""
%{!?kernel_version:%{expand:%%global kernel_version %{kernel_version_latest}}}
%endif

%global _use_internal_dependency_generator 0
%global __find_requires %{nil}
%global __find_provides /usr/lib/rpm/find-provides

%global debug_package %{nil}

%global __spec_install_post \
  %{?__debug_package:%{__debug_install_post}} \
  %{__arch_install_post} \
  %{__os_install_post} \
  %{__mod_compress_install_post}

%global __mod_compress_install_post find %{buildroot}/lib/modules -type f -name \*.ko -exec xz \{\} \\;


Name:             kmod-%{pkg}
Version:          5.7
Release:          3%{?dist}
Summary:          SysKonnect/Marvell Yukon Gigabit Ethernet (%{pkg}) driver

License:          GPLv2
URL:              https://www.kernel.org/

Source0:          %{pkg}-%{version}.tar.xz

ExclusiveArch:    x86_64 aarch64

BuildRequires:    elfutils-libelf-devel
BuildRequires:    gcc
BuildRequires:    kmod
BuildRequires:    make
BuildRequires:    redhat-rpm-config
BuildRequires:    xz

%{!?kernel_version:
BuildRequires:    kernel-devel >= %{kernel_version_min}
}

%{?kernel_version:
BuildRequires:    kernel-devel = %{kernel_version}
BuildRequires:    kernel-devel-uname-r = %{kernel_version}.%{_arch}

Requires:         kernel-core = %{kernel_version}
Requires:         kernel-core-uname-r = %{kernel_version}.%{_arch}
Requires:         kernel-modules = %{kernel_version}
Requires:         kernel-modules-uname-r = %{kernel_version}.%{_arch}

Provides:         installonlypkg(kernel-module)
Provides:         %{name}-%{kernel_version}.%{_arch} = %{?epoch:%{epoch}:}%{version}-%{release}
}

Requires(post):   /usr/sbin/depmod
Requires(postun): /usr/sbin/depmod

Requires(post):   /usr/bin/dracut
Requires(postun): /usr/bin/dracut


%description
This driver supports Gigabit Ethernet adapters based on the Marvell Yukon
chipset:

- 0x10B7:0x1700: 3Com 3C940
- 0x10B7:0x80EB: 3Com 3C940B
- 0x1148:0x4300: SysKonnect SK-9xx
- 0x1148:0x4320: SysKonnect SK-98xx V2.0
- 0x1186:0x4302: D-Link DGE-530T Rev C1
- 0x1186:0x4B01: D-Link DGE-530T Rev B
- 0x1186:0x4C00: D-Link DGE-530T
- 0x11AB:0x4320: Marvell Yukon 88E8001/8003/8010
- 0x11AB:0x5005: Belkin
- 0x1371:0x434E: CNet PowerG-2000
- 0x1737:0x1032:*:0x0015: Linksys EG1032 v2
- 0x1737:0x1064: Linksys EG1064 v2


%prep
%autosetup -p1 -n %{pkg}-%{version}


%build
pushd src
%{__make} -C /usr/src/kernels/%{kernel_version}.%{_arch} %{?_smp_mflags} M=$PWD modules
popd


%install
%{__install} -D -t %{buildroot}/lib/modules/%{kernel_version}.%{_arch}/extra/drivers/net/ethernet/marvell src/%{pkg}.ko

# Make .ko objects temporarily executable for automatic stripping
find %{buildroot}/lib/modules -type f -name \*.ko -exec chmod u+x \{\} \+


%clean
%{__rm} -rf %{buildroot}


%post
mkdir -p %{_localstatedir}/lib/rpm-state/sig-kmods
touch %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch}


%preun
mkdir -p %{_localstatedir}/lib/rpm-state/sig-kmods
touch %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch}


%postun
if [ -f %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch} ]
then
    if [ -f /lib/modules/%{kernel_version}.%{_arch}/System.map ]
    then
        /usr/sbin/depmod -aeF /lib/modules/%{kernel_version}.%{_arch}/System.map %{kernel_version}.%{_arch}
    fi

    if [ -f /boot/initramfs-%{kernel_version}.%{_arch}.img ]
    then
        if /usr/bin/dracut -f --rebuild /boot/initramfs-%{kernel_version}.%{_arch}.img /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew %{kernel_version}.%{_arch}
        then
            if ! cmp -s /boot/initramfs-%{kernel_version}.%{_arch}.img /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew
            then
                mv /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew /boot/initramfs-%{kernel_version}.%{_arch}.img
            else
                rm -f /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew
            fi
        fi
    fi

    rm -f %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch}
    rmdir --ignore-fail-on-non-empty %{_localstatedir}/lib/rpm-state/sig-kmods
fi


%posttrans
if [ -f %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch} ]
then
    if [ -f /lib/modules/%{kernel_version}.%{_arch}/System.map ]
    then
        /usr/sbin/depmod -aeF /lib/modules/%{kernel_version}.%{_arch}/System.map %{kernel_version}.%{_arch}
    fi

    if [ -f /boot/initramfs-%{kernel_version}.%{_arch}.img ]
    then
        if /usr/bin/dracut -f --rebuild /boot/initramfs-%{kernel_version}.%{_arch}.img /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew %{kernel_version}.%{_arch}
        then
            if ! cmp -s /boot/initramfs-%{kernel_version}.%{_arch}.img /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew
            then
                mv /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew /boot/initramfs-%{kernel_version}.%{_arch}.img
            else
                rm -f /boot/initramfs-%{kernel_version}.%{_arch}.img.rpmnew
            fi
        fi
    fi

    rm -f %{_localstatedir}/lib/rpm-state/sig-kmods/%{kernel_version}.%{_arch}
    rmdir --ignore-fail-on-non-empty %{_localstatedir}/lib/rpm-state/sig-kmods
fi


%files
%defattr(644,root,root,755)
/lib/modules/%{kernel_version}.%{_arch}
%license COPYING


%changelog
* Thu Aug 19 2021 Peter Georg <peter.georg@physik.uni-regensburg.de> - 5.7-3
- Rebuild for 4.18.0-331.el8

* Wed Aug 11 2021 Peter Georg <peter.georg@physik.uni-regensburg.de> - 5.7-2
- Rebuild for 4.18.0-326.el8
- Fix provides/requires
- Fix kernel dependencies
- Add convenient provides kmod-aacraid-`uname -r`
- Fix installonlypkg detection
- Recreate source tarballs
- Rebuild for dist = .el8s

* Thu Jul 22 2021 Peter Georg <peter.georg@physik.uni-regensburg.de> - 5.7-1
- Initial version
